0.1.15 (mai 13, 2024)
=====================
A new minor release with fixes such as setting random seeds and enhancing parallelization, alongside improvements like automated package building, documentation updates, and maintenance tasks.

  * FIX: Set random seed in registration test (#160)
  * FIX: Implement parallelization with joblib & processes (#103)
  * FIX: Revise ``antsRegistration`` arguments (just FYI) (#102)
  * FIX: Revising parallel execution and related housekeeping (#100)
  * FIX: Stop using overly complicated asyncio for managing ThreadPoolExecutors (#97)
  * FIX: Housekeeping of the data loader function (#92)
  * FIX: Integration test with B0 (trivial) model (#85)
  * FIX: Generate temporary H5 cache path anew with every new instance of ``DWI`` (#87)
  * FIX: Miscelaneous revisions to make tests execute properly (#84)
  * FIX: Fix Sphinx documentation configuration file (#136)
  * ENH: Use img shields license badge and point to file (#190)
  * ENH: Add test for the CLI parser (#183)
  * ENH: Automated Package Building and Deployment (#179)
  * ENH: CLI Implementation for Eddymotion (#157)
  * ENH: Rename the estimator method to honor its purpose/use (#173)
  * ENH: Bump CircleCI docker image (#177)
  * ENH: Require the iterables in a zip call to have equal length (#172)
  * ENH: Adopt the NiPreps author update maintenance script (#167)
  * ENH: Drop support for Python 3.8 and 3.9 (#158)
  * ENH: Remove unused `tmp_path` parameter from test (#162)
  * ENH: Outsource leave-one-out splitter so it can be used across data types (#98)
  * ENH: Simplify `eddymotion.estimator.EddyMotionEstimator.fit` (#149)
  * ENH: Refactor code linter and formatter dependencies (#144)
  * ENH: Use NumPy's `Generator` class as a replacement for `RandomState` (#141)
  * ENH: Define instance attributes in ``__init__`` method (#133)
  * ENH: Remove unused parameter from method prototype (#134)
  * ENH: Add Python 3.12 to project classifiers (#143)
  * ENH: Fix GitHub workflow actions warnings linked to `Node.js` (#130)
  * ENH: Remove unnecessary `docs/requirements.txt` (#137)
  * ENH: Refactor package structure (#115)
  * ENH: Model building refactor (#109)
  * ENH: Add ``FullDKIModel`` (#91)
  * ENH: PET uptake model (#112)
  * ENH: Allow mix-and-matching of models (#105)
  * ENH: Improvements to the estimator (#96)
  * ENH: Adds carpet_plot function (#123)
  * ENH: Data utils (#124)
  * ENH: Changed em_affines from Affine object to matrix with preallocation (#122)
  * DOC: Fix typo in ModelFactory docstring (#185)
  * DOC: Fix grammar in model factory docstring (#175)
  * DOC: Remove unnamed return parameter from docstring (#164)
  * DOC: Add CircleCI status badge to README (#159)
  * DOC: Add status badges to ``README`` file (#138)
  * DOC: Add missing references in `README` file (#131)
  * DOC: Miscellaneous documentation fixes (#135)
  * DOC: Fix documentation build (#104)
  * DOC: Just added myself to contributors (#83)
  * DOC: Update contact information for @dpys and setup.cfg -> nipreps (#119)
  * DOC: Update contact information for @dpys and setup.cfg -> nipreps (#119)
  * STY: fix style errors (#154)
  * STY: Format the code base style (#147)
  * STY: Avoid using `pytest` `tmpdir` fixture as variable name (#132)
  * MAINT: Drop local version to play nicely with test.pypi.org (#182)
  * MAINT: Migrate to PEP517/518 packaging (#128)
  * MAINT: Rotate CircleCI secrets and setup up org-level context (#121)
  * MAINT: Pin Python >= 3.8 (#120)
  * MAINT: Do not install ants with conda (CircleCI) (#106)
  * MAINT: Do not install ants with conda (CircleCI) (#106)
  * MAINT: Initiate CircleCI's config file (#88)
  * MAINT: Reduce jobs in contrib GHA (#82)
  * CI: replace flake8 by ruff check (#139)

0.1.4 (April 12, 2021)
======================
The first release following a more complete deployment cycle.

* FIX: Bad argument mapping in the new plot_gradients (#33)
* FIX: Use consistent names for DTI/DKI. (#30)
* ENH: Add general crediting system (#32)
* ENH: Implement method to plot DWI gradient (#27)
* ENH: Licensing and stylistic suggestions (#2)
* MAINT: Update main from upstream nipreps/EddyMotionCorrection (#1)
